@@ -1,4 +1,5 @@
 import dataclasses
+import numpy as np
 
 from dt_duckiematrix_messages import CBorMessage
 
@@ -13,3 +14,6 @@ class CameraFrame(CBorMessage):
     @classmethod
     def from_jpeg(cls, jpeg: bytes) -> 'CameraFrame':
         return CameraFrame("jpeg", 0, 0, jpeg)
+
+    def as_uint8(self) -> np.ndarray:
+        return np.frombuffer(self.frame, np.uint8)
